@@ -11,42 +11,53 @@ use namespace::clean;
 
     sub config_file
     {
-        my ( $class, $new_value ) = @_;
+        my ( $invocant, $new_value ) = @_;
         return $value unless @_ > 1;
         $value = $new_value;
-        return $class;
+        return $invocant;
     }
 }
 
 {
     my $value = __PACKAGE__->parse_config_file;
 
+    sub reload_config
+    {
+        my ( $invocant ) = @_;
+        $value = $invocant->parse_config_file;
+        return $invocant;
+    }
+
     sub config
     {
-        my ( $class, $new_value ) = @_;
+        my ( $invocant, $new_value ) = @_;
         return $value unless @_ > 1;
         $value = $new_value;
-        return $class;
+        return $invocant;
     }
 }
 
 sub parse_config_file
 {
     my ( $class ) = @_;
-    my $config_file = __PACKAGE__->config_file;
+    $class = ref( $class ) || $class;
+    my $config_file = $class->config_file;
     unless ( -e $config_file ) {
         print STDERR << "EOF";
 Oops!
-Configuration file not found:
+
+Your configuration file not found. Without it, your API requests may not be
+authorized if you haven't used "Shippo->api_key(...)" to set your Shippo
+API key.
 
     $config_file
 
-It should look something like this:
+You should create the file mentioned above. It's a YAML file that should look
+something like this.
 
 ---
 private_token: <YOUR PRIVATE API AUTHENTICATION TOKEN>
 public_token: <YOUR PUBLISHABLE API AUTHENTICATION TOKEN>
-default_token: private_token
 EOF
         return {};
     }
@@ -54,7 +65,14 @@ EOF
         or croak "Can't open file '$config_file': $!";
     my $config_yaml = do { local $/ = <$fh> };
     close $fh;
-    return YAML::XS::Load( $config_yaml );
+    return bless( YAML::XS::Load( $config_yaml ), $class );
+}
+
+BEGIN {
+    no warnings 'once';
+    # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
+    # namespace is just cruel; allow the use of "Shippo", too.
+    *Shippo::Config:: = *WebService::Shippo::Config::;
 }
 
 1;
